@@ -8,9 +8,6 @@ See :doc:`/specs/avanti/avanti`.
 
 """
 
-from __future__ import unicode_literals
-from builtins import str
-
 from lino.api import dd, rt, _
 from django.db import models
 from django.db.models import Q
@@ -40,20 +37,14 @@ from lino_xl.lib.cal.mixins import EventGenerator
 from lino_xl.lib.cal.workflows import TaskStates
 from lino_xl.lib.cv.mixins import BiographyOwner
 # from lino.utils.mldbc.fields import BabelVirtualField
-
 from lino.mixins import ObservedDateRange
-
 from lino_xl.lib.clients.choicelists import ClientEvents, ClientStates
-
-
+from lino.core.roles import Explorer
+from lino_xl.lib.cv.roles import CareerUser
 
 from .choicelists import TranslatorTypes, StartingReasons, ProfessionalStates
-
 from .choicelists import OldEndingReasons
-
-from lino.core.roles import Explorer
 from .roles import ClientsNameUser, ClientsUser, ClientsStaff
-from lino_xl.lib.cv.roles import CareerUser
 
 contacts = dd.resolve_app('contacts')
 
@@ -234,18 +225,6 @@ class Client(contacts.Person, BeIdCardHolder, UserAuthored,
         return _("({}) from {}").format( self.pk, self.city)
         # return "{} {}".format(self._meta.verbose_name, self.pk)
 
-    @dd.displayfield(_("Name"))
-    def name_column(self, ar):
-        return str(self)
-
-    @dd.displayfield(_("Municipality"))
-    def municipality(self, ar):
-        pl = self.city
-        mt = dd.plugins.avanti.municipality_type
-        while pl and pl.parent_id and pl.type and pl.type.value > mt:
-            pl = pl.parent
-        return str(pl)
-
     def get_overview_elems(self, ar):
         elems = super(Client, self).get_overview_elems(ar)
         # elems.append(E.br())
@@ -658,6 +637,7 @@ add = ClientStates.add_item
 add('05', _("Incoming"), 'incoming')
 add('07', _("Informed"), 'informed')
 add('10', _("Newcomer"), 'newcomer')
+add('15', pgettext("client state", "Equal"), 'equal')  # Gleichgestellt
 add('20', pgettext("client state", "Registered"), 'coached')
 add('25', _("Inactive"), 'inactive')
 add('30', _("Ended"), 'former')
